/*
 *  Copyright 2017-2022 Adobe.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *          http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package com.adobe.testing.s3mock.dto;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonRootName;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlElementWrapper;
import java.util.ArrayList;
import java.util.List;

/**
 * Request to complete multipart upload.
 * https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html
 */
@JsonRootName("CompleteMultipartUpload")
public class CompleteMultipartUploadRequest {

  @JsonProperty("Part")
  @JacksonXmlElementWrapper(useWrapping = false)
  private List<CompletedPart> parts = new ArrayList<>();

  public void setPart(CompletedPart part) {
    this.parts.add(part);
  }

  public void setParts(List<CompletedPart> parts) {
    this.parts = parts;
  }

  public List<CompletedPart> getParts() {
    return parts;
  }

}
